@@ -1,28 +1,52 @@
 /* ----------------------------------------------------------------------
-   LIGGGHTS® - LAMMPS Improved for General Granular and Granular Heat
-   Transfer Simulations
+    This is the
 
-   LIGGGHTS® is part of CFDEM®project
-   www.liggghts.com | www.cfdem.com
+    ██╗     ██╗ ██████╗  ██████╗  ██████╗ ██╗  ██╗████████╗███████╗
+    ██║     ██║██╔════╝ ██╔════╝ ██╔════╝ ██║  ██║╚══██╔══╝██╔════╝
+    ██║     ██║██║  ███╗██║  ███╗██║  ███╗███████║   ██║   ███████╗
+    ██║     ██║██║   ██║██║   ██║██║   ██║██╔══██║   ██║   ╚════██║
+    ███████╗██║╚██████╔╝╚██████╔╝╚██████╔╝██║  ██║   ██║   ███████║
+    ╚══════╝╚═╝ ╚═════╝  ╚═════╝  ╚═════╝ ╚═╝  ╚═╝   ╚═╝   ╚══════╝®
 
-   This file was modified with respect to the release in LAMMPS
-   Modifications are Copyright 2009-2012 JKU Linz
-                     Copyright 2012-     DCS Computing GmbH, Linz
+    DEM simulation engine, released by
+    DCS Computing Gmbh, Linz, Austria
+    http://www.dcs-computing.com, office@dcs-computing.com
 
-   LIGGGHTS® and CFDEM® are registered trade marks of DCS Computing GmbH,
-   the producer of the LIGGGHTS® software and the CFDEM®coupling software
-   See http://www.cfdem.com/terms-trademark-policy for details.
+    LIGGGHTS® is part of CFDEM®project:
+    http://www.liggghts.com | http://www.cfdem.com
 
-   LAMMPS - Large-scale Atomic/Molecular Massively Parallel Simulator
-   http://lammps.sandia.gov, Sandia National Laboratories
-   Steve Plimpton, sjplimp@sandia.gov
+    Core developer and main author:
+    Christoph Kloss, christoph.kloss@dcs-computing.com
 
-   Copyright (2003) Sandia Corporation.  Under the terms of Contract
-   DE-AC04-94AL85000 with Sandia Corporation, the U.S. Government retains
-   certain rights in this software.  This software is distributed under
-   the GNU General Public License.
+    LIGGGHTS® is open-source, distributed under the terms of the GNU Public
+    License, version 2 or later. It is distributed in the hope that it will
+    be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
+    of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. You should have
+    received a copy of the GNU General Public License along with LIGGGHTS®.
+    If not, see http://www.gnu.org/licenses . See also top-level README
+    and LICENSE files.
 
-   See the README file in the top-level directory.
+    LIGGGHTS® and CFDEM® are registered trade marks of DCS Computing GmbH,
+    the producer of the LIGGGHTS® software and the CFDEM®coupling software
+    See http://www.cfdem.com/terms-trademark-policy for details.
+
+-------------------------------------------------------------------------
+    Contributing author and copyright for this file:
+    This file is from LAMMPS, but has been modified. Copyright for
+    modification:
+
+    Copyright 2012-     DCS Computing GmbH, Linz
+    Copyright 2009-2012 JKU Linz
+
+    Copyright of original file:
+    LAMMPS - Large-scale Atomic/Molecular Massively Parallel Simulator
+    http://lammps.sandia.gov, Sandia National Laboratories
+    Steve Plimpton, sjplimp@sandia.gov
+
+    Copyright (2003) Sandia Corporation.  Under the terms of Contract
+    DE-AC04-94AL85000 with Sandia Corporation, the U.S. Government retains
+    certain rights in this software.  This software is distributed under
+    the GNU General Public License.
 ------------------------------------------------------------------------- */
 
 #include "math.h"
@@ -81,11 +105,13 @@ void AtomVecSphere::init()
 
   // set radvary if particle diameters are time-varying due to some fix
   for (int i = 0; i < modify->nfix; i++)
+  {
       if (modify->fix[i]->rad_mass_vary_flag) {
         radvary = 1;
-        size_forward = 6; 
+        size_forward = 7; 
         comm_x_only = 1;
       }
+  }
 
   if(radvary) atom->radvary_flag = 1;
 }
@@ -208,6 +234,7 @@ int AtomVecSphere::pack_comm(int n, int *list, double *buf,
         buf[m++] = x[j][0];
         buf[m++] = x[j][1];
         buf[m++] = x[j][2];
+        buf[m++] = ubuf(type[j]).d; 
         buf[m++] = radius[j];
         buf[m++] = rmass[j];
         buf[m++] = density[j]; 
@@ -227,6 +254,7 @@ int AtomVecSphere::pack_comm(int n, int *list, double *buf,
         buf[m++] = x[j][0] + dx;
         buf[m++] = x[j][1] + dy;
         buf[m++] = x[j][2] + dz;
+        buf[m++] = ubuf(type[j]).d; 
         buf[m++] = radius[j];
         buf[m++] = rmass[j];
         buf[m++] = density[j]; 
@@ -320,6 +348,7 @@ int AtomVecSphere::pack_comm_vel(int n, int *list, double *buf,
         buf[m++] = x[j][0];
         buf[m++] = x[j][1];
         buf[m++] = x[j][2];
+        buf[m++] = ubuf(type[j]).d; 
         buf[m++] = radius[j];
         buf[m++] = rmass[j];
         buf[m++] = density[j]; 
@@ -346,6 +375,7 @@ int AtomVecSphere::pack_comm_vel(int n, int *list, double *buf,
           buf[m++] = x[j][0] + dx;
           buf[m++] = x[j][1] + dy;
           buf[m++] = x[j][2] + dz;
+          buf[m++] = ubuf(type[j]).d; 
           buf[m++] = radius[j];
           buf[m++] = rmass[j];
           buf[m++] = density[j]; 
@@ -365,6 +395,7 @@ int AtomVecSphere::pack_comm_vel(int n, int *list, double *buf,
           buf[m++] = x[j][0] + dx;
           buf[m++] = x[j][1] + dy;
           buf[m++] = x[j][2] + dz;
+          buf[m++] = ubuf(type[j]).d; 
           buf[m++] = radius[j];
           buf[m++] = rmass[j];
           buf[m++] = density[j]; 
@@ -399,6 +430,7 @@ int AtomVecSphere::pack_comm_hybrid(int n, int *list, double *buf)
   m = 0;
   for (i = 0; i < n; i++) {
     j = list[i];
+    buf[m++] = ubuf(type[j]).d; 
     buf[m++] = radius[j];
     buf[m++] = rmass[j];
     buf[m++] = density[j];
@@ -427,6 +459,7 @@ void AtomVecSphere::unpack_comm(int n, int first, double *buf)
       x[i][0] = buf[m++];
       x[i][1] = buf[m++];
       x[i][2] = buf[m++];
+      type[i] = (int) ubuf(buf[m++]).i; 
       radius[i] = buf[m++];
       rmass[i] = buf[m++];
       density[i] = buf[m++]; 
@@ -462,6 +495,7 @@ void AtomVecSphere::unpack_comm_vel(int n, int first, double *buf)
       x[i][0] = buf[m++];
       x[i][1] = buf[m++];
       x[i][2] = buf[m++];
+      type[i] = (int) ubuf(buf[m++]).i; 
       radius[i] = buf[m++];
       rmass[i] = buf[m++];
       density[i] = buf[m++]; 
@@ -486,6 +520,7 @@ int AtomVecSphere::unpack_comm_hybrid(int n, int first, double *buf)
   m = 0;
   last = first + n;
   for (i = first; i < last; i++) {
+    type[i] = (int) ubuf(buf[m++]).i; 
     radius[i] = buf[m++];
     rmass[i] = buf[m++];
     density[i] = buf[m++]; 
