@@ -1,14 +1,46 @@
 /* ----------------------------------------------------------------------
-   LAMMPS - Large-scale Atomic/Molecular Massively Parallel Simulator
-   http://lammps.sandia.gov, Sandia National Laboratories
-   Steve Plimpton, sjplimp@sandia.gov
+    This is the
 
-   Copyright (2003) Sandia Corporation.  Under the terms of Contract
-   DE-AC04-94AL85000 with Sandia Corporation, the U.S. Government retains
-   certain rights in this software.  This software is distributed under
-   the GNU General Public License.
+    ██╗     ██╗ ██████╗  ██████╗  ██████╗ ██╗  ██╗████████╗███████╗
+    ██║     ██║██╔════╝ ██╔════╝ ██╔════╝ ██║  ██║╚══██╔══╝██╔════╝
+    ██║     ██║██║  ███╗██║  ███╗██║  ███╗███████║   ██║   ███████╗
+    ██║     ██║██║   ██║██║   ██║██║   ██║██╔══██║   ██║   ╚════██║
+    ███████╗██║╚██████╔╝╚██████╔╝╚██████╔╝██║  ██║   ██║   ███████║
+    ╚══════╝╚═╝ ╚═════╝  ╚═════╝  ╚═════╝ ╚═╝  ╚═╝   ╚═╝   ╚══════╝®
 
-   See the README file in the top-level LAMMPS directory.
+    DEM simulation engine, released by
+    DCS Computing Gmbh, Linz, Austria
+    http://www.dcs-computing.com, office@dcs-computing.com
+
+    LIGGGHTS® is part of CFDEM®project:
+    http://www.liggghts.com | http://www.cfdem.com
+
+    Core developer and main author:
+    Christoph Kloss, christoph.kloss@dcs-computing.com
+
+    LIGGGHTS® is open-source, distributed under the terms of the GNU Public
+    License, version 2 or later. It is distributed in the hope that it will
+    be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
+    of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. You should have
+    received a copy of the GNU General Public License along with LIGGGHTS®.
+    If not, see http://www.gnu.org/licenses . See also top-level README
+    and LICENSE files.
+
+    LIGGGHTS® and CFDEM® are registered trade marks of DCS Computing GmbH,
+    the producer of the LIGGGHTS® software and the CFDEM®coupling software
+    See http://www.cfdem.com/terms-trademark-policy for details.
+
+-------------------------------------------------------------------------
+    Contributing author and copyright for this file:
+    This file is from LAMMPS
+    LAMMPS - Large-scale Atomic/Molecular Massively Parallel Simulator
+    http://lammps.sandia.gov, Sandia National Laboratories
+    Steve Plimpton, sjplimp@sandia.gov
+
+    Copyright (2003) Sandia Corporation.  Under the terms of Contract
+    DE-AC04-94AL85000 with Sandia Corporation, the U.S. Government retains
+    certain rights in this software.  This software is distributed under
+    the GNU General Public License.
 ------------------------------------------------------------------------- */
 
 /* ----------------------------------------------------------------------
@@ -60,6 +92,8 @@ FixAveSpatial::FixAveSpatial(LAMMPS *lmp, int narg, char **arg) :
   global_freq = nfreq;
   no_change_box = 1;
 
+  write_ts_ = true;
+
   ndim = 0;
   int iarg = 6;
   while (iarg < narg && ndim < 3) {
@@ -76,7 +110,7 @@ FixAveSpatial::FixAveSpatial(LAMMPS *lmp, int narg, char **arg) :
     else if (strcmp(arg[iarg+1],"center") == 0) originflag[ndim] = CENTER;
     else if (strcmp(arg[iarg+1],"upper") == 0) originflag[ndim] = UPPER;
     else originflag[ndim] = COORD;
-    if (originflag[ndim] == COORD) 
+    if (originflag[ndim] == COORD)
       origin[ndim] = force->numeric(FLERR,arg[iarg+1]);
 
     delta[ndim] = force->numeric(FLERR,arg[iarg+2]);
@@ -212,6 +246,14 @@ FixAveSpatial::FixAveSpatial(LAMMPS *lmp, int narg, char **arg) :
         }
       }
       iarg += 2;
+    } else if (strcmp(arg[iarg],"write_ts") == 0) { 
+      if (iarg+2 > narg) error->all(FLERR,"Illegal fix ave/spatial command");
+      if(strcmp(arg[iarg+1],"yes") == 0)
+        write_ts_ = true;
+      else if(strcmp(arg[iarg+1],"no") == 0)
+        write_ts_ = false;
+      else error->all(FLERR,"Illegal fix ave/spatial command");
+      iarg += 2;
     } else if (strcmp(arg[iarg],"ave") == 0) {
       if (iarg+2 > narg) error->all(FLERR,"Illegal fix ave/spatial command");
       if (strcmp(arg[iarg+1],"one") == 0) ave = ONE;
@@ -327,13 +369,13 @@ FixAveSpatial::FixAveSpatial(LAMMPS *lmp, int narg, char **arg) :
   // print file comment lines
 
   if (fp && me == 0) {
-    if (title1) fprintf(fp,"%s\n",title1);
-    else fprintf(fp,"# Spatial-averaged data for fix %s and group %s\n",
+    if (title1 && strlen (title1) > 1) fprintf(fp,"%s\n",title1);
+    else if(!title1) fprintf(fp,"# Spatial-averaged data for fix %s and group %s\n",
                  id,arg[1]);
-    if (title2) fprintf(fp,"%s\n",title2);
-    else fprintf(fp,"# Timestep Number-of-bins\n");
-    if (title3) fprintf(fp,"%s\n",title3);
-    else {
+    if (title2 && strlen (title2) > 1) fprintf(fp,"%s\n",title2);
+    else if(!title2) fprintf(fp,"# Timestep Number-of-bins\n");
+    if (title3 && strlen (title3) > 1) fprintf(fp,"%s\n",title3);
+    else if(!title3) {
       if (ndim == 1) fprintf(fp,"# Bin Coord Ncount");
       else if (ndim == 2) fprintf(fp,"# Bin Coord1 Coord2 Ncount");
       else if (ndim == 3) fprintf(fp,"# Bin Coord1 Coord2 Coord3 Ncount");
@@ -832,7 +874,7 @@ void FixAveSpatial::end_of_step()
 
   if (fp && me == 0) {
     if (overwrite) fseek(fp,filepos,SEEK_SET);
-    fprintf(fp,BIGINT_FORMAT " %d\n",ntimestep,nbins);
+    if(write_ts_) fprintf(fp,BIGINT_FORMAT " %d\n",ntimestep,nbins);
     if (ndim == 1)
       for (m = 0; m < nbins; m++) {
         fprintf(fp,"  %d %g %g",m+1,coord[m][0],
@@ -913,7 +955,7 @@ void FixAveSpatial::end_of_step()
         }
       }
     }
-    
+
     if (n_samples != 0) {
       for (i = 0; i < nvalues; i++) {
         samples_average = count_samples / n_samples; // average # particles per sample
