@@ -1,38 +1,53 @@
 /* ----------------------------------------------------------------------
-   LIGGGHTS® - LAMMPS Improved for General Granular and Granular Heat
-   Transfer Simulations
+    This is the
 
-   LIGGGHTS® is part of CFDEM®project
-   www.liggghts.com | www.cfdem.com
+    ██╗     ██╗ ██████╗  ██████╗  ██████╗ ██╗  ██╗████████╗███████╗
+    ██║     ██║██╔════╝ ██╔════╝ ██╔════╝ ██║  ██║╚══██╔══╝██╔════╝
+    ██║     ██║██║  ███╗██║  ███╗██║  ███╗███████║   ██║   ███████╗
+    ██║     ██║██║   ██║██║   ██║██║   ██║██╔══██║   ██║   ╚════██║
+    ███████╗██║╚██████╔╝╚██████╔╝╚██████╔╝██║  ██║   ██║   ███████║
+    ╚══════╝╚═╝ ╚═════╝  ╚═════╝  ╚═════╝ ╚═╝  ╚═╝   ╚═╝   ╚══════╝®
 
-   Christoph Kloss, christoph.kloss@cfdem.com
-   Copyright 2009-2012 JKU Linz
-   Copyright 2012-     DCS Computing GmbH, Linz
+    DEM simulation engine, released by
+    DCS Computing Gmbh, Linz, Austria
+    http://www.dcs-computing.com, office@dcs-computing.com
 
-   LIGGGHTS® and CFDEM® are registered trade marks of DCS Computing GmbH,
-   the producer of the LIGGGHTS® software and the CFDEM®coupling software
-   See http://www.cfdem.com/terms-trademark-policy for details.
+    LIGGGHTS® is part of CFDEM®project:
+    http://www.liggghts.com | http://www.cfdem.com
 
-   LIGGGHTS® is based on LAMMPS
-   LAMMPS - Large-scale Atomic/Molecular Massively Parallel Simulator
-   http://lammps.sandia.gov, Sandia National Laboratories
-   Steve Plimpton, sjplimp@sandia.gov
+    Core developer and main author:
+    Christoph Kloss, christoph.kloss@dcs-computing.com
 
-   This software is distributed under the GNU General Public License.
+    LIGGGHTS® is open-source, distributed under the terms of the GNU Public
+    License, version 2 or later. It is distributed in the hope that it will
+    be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
+    of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. You should have
+    received a copy of the GNU General Public License along with LIGGGHTS®.
+    If not, see http://www.gnu.org/licenses . See also top-level README
+    and LICENSE files.
 
-   See the README file in the top-level directory.
+    LIGGGHTS® and CFDEM® are registered trade marks of DCS Computing GmbH,
+    the producer of the LIGGGHTS® software and the CFDEM®coupling software
+    See http://www.cfdem.com/terms-trademark-policy for details.
+
+-------------------------------------------------------------------------
+    Contributing author and copyright for this file:
+    Christoph Kloss (DCS Computing GmbH, Linz, JKU Linz)
+    Richard Berger (JKU Linz)
+
+    Copyright 2012-     DCS Computing GmbH, Linz
+    Copyright 2009-2012 JKU Linz
 ------------------------------------------------------------------------- */
 
-/* ----------------------------------------------------------------------
-   Contributing authors:
-   Christoph Kloss (JKU Linz, DCS Computing GmbH, Linz)
-   Richard Berger (JKU Linz)
-------------------------------------------------------------------------- */
 #ifdef NORMAL_MODEL
+
 NORMAL_MODEL(HOOKE,hooke,0)
+
 #else
+
 #ifndef NORMAL_MODEL_HOOKE_H_
 #define NORMAL_MODEL_HOOKE_H_
+
 #include "contact_models.h"
 #include "math.h"
 #include "atom.h"
@@ -46,7 +61,7 @@ namespace ContactModels
   class NormalModel<HOOKE> : protected Pointers
   {
   public:
-    static const int MASK = CM_REGISTER_SETTINGS | CM_CONNECT_TO_PROPERTIES | CM_COLLISION;
+    static const int MASK = CM_REGISTER_SETTINGS | CM_CONNECT_TO_PROPERTIES | CM_SURFACES_INTERSECT;
 
     NormalModel(LAMMPS * lmp, IContactHistorySetup*) : Pointers(lmp),
       Yeff(NULL),
@@ -109,14 +124,14 @@ namespace ContactModels
       return 1.;
     }
 
-    inline void collision(CollisionData & cdata, ForceData & i_forces, ForceData & j_forces)
+    inline void surfacesIntersect(SurfacesIntersectData & sidata, ForceData & i_forces, ForceData & j_forces)
     {
-      const int itype = cdata.itype;
-      const int jtype = cdata.jtype;
-      double ri = cdata.radi;
-      double rj = cdata.radj;
-      double reff=cdata.is_wall ? ri : (ri*rj/(ri+rj));
-      double meff=cdata.meff;
+      const int itype = sidata.itype;
+      const int jtype = sidata.jtype;
+      double ri = sidata.radi;
+      double rj = sidata.radj;
+      double reff=sidata.is_wall ? ri : (ri*rj/(ri+rj));
+      double meff=sidata.meff;
       double coeffRestLogChosen;
 
       const double sqrtval = sqrt(reff);
@@ -137,7 +152,7 @@ namespace ContactModels
       }
       if (viscous)  {
          // Stokes Number from MW Schmeeckle (2001)
-         const double stokes=cdata.meff*cdata.vn/(6.0*M_PI*coeffMu[itype][jtype]*reff*reff);
+         const double stokes=sidata.meff*sidata.vn/(6.0*M_PI*coeffMu[itype][jtype]*reff*reff);
          // Empirical from Legendre (2006)
          coeffRestLogChosen=log(coeffRestMax[itype][jtype])+coeffStc[itype][jtype]/stokes;
       } else {
@@ -154,8 +169,8 @@ namespace ContactModels
       kn /= force->nktv2p;
       kt /= force->nktv2p;
 
-      const double Fn_damping = -gamman*cdata.vn;
-      const double Fn_contact = kn*(cdata.radsum-cdata.r);
+      const double Fn_damping = -gamman*sidata.vn;
+      const double Fn_contact = kn*(sidata.radsum-sidata.r);
       double Fn                         = Fn_damping + Fn_contact;
 
       //limit force to avoid the artefact of negative repulsion force
@@ -163,23 +178,23 @@ namespace ContactModels
       {
           Fn = 0.0;
       }
-      cdata.Fn = Fn;
+      sidata.Fn = Fn;
 
-      cdata.kn = kn;
-      cdata.kt = kt;
-      cdata.gamman = gamman;
-      cdata.gammat = gammat;
+      sidata.kn = kn;
+      sidata.kt = kt;
+      sidata.gamman = gamman;
+      sidata.gammat = gammat;
 
       // apply normal force
-      if(cdata.is_wall) {
-        const double Fn_ = Fn * cdata.area_ratio;
-        i_forces.delta_F[0] = Fn_ * cdata.en[0];
-        i_forces.delta_F[1] = Fn_ * cdata.en[1];
-        i_forces.delta_F[2] = Fn_ * cdata.en[2];
+      if(sidata.is_wall) {
+        const double Fn_ = Fn * sidata.area_ratio;
+        i_forces.delta_F[0] = Fn_ * sidata.en[0];
+        i_forces.delta_F[1] = Fn_ * sidata.en[1];
+        i_forces.delta_F[2] = Fn_ * sidata.en[2];
       } else {
-        const double fx = cdata.Fn * cdata.en[0];
-        const double fy = cdata.Fn * cdata.en[1];
-        const double fz = cdata.Fn * cdata.en[2];
+        const double fx = sidata.Fn * sidata.en[0];
+        const double fy = sidata.Fn * sidata.en[1];
+        const double fz = sidata.Fn * sidata.en[2];
 
         i_forces.delta_F[0] = fx;
         i_forces.delta_F[1] = fy;
@@ -191,9 +206,9 @@ namespace ContactModels
       }
     }
 
-    inline void noCollision(ContactData&, ForceData&, ForceData&){}
-    void beginPass(CollisionData&, ForceData&, ForceData&){}
-    void endPass(CollisionData&, ForceData&, ForceData&){}
+    inline void surfacesClose(SurfacesCloseData&, ForceData&, ForceData&){}
+    void beginPass(SurfacesIntersectData&, ForceData&, ForceData&){}
+    void endPass(SurfacesIntersectData&, ForceData&, ForceData&){}
 
   protected:
     double ** Yeff;
