@@ -1,38 +1,55 @@
 /* ----------------------------------------------------------------------
-   LIGGGHTS® - LAMMPS Improved for General Granular and Granular Heat
-   Transfer Simulations
+    This is the
 
-   LIGGGHTS® is part of CFDEM®project
-   www.liggghts.com | www.cfdem.com
+    ██╗     ██╗ ██████╗  ██████╗  ██████╗ ██╗  ██╗████████╗███████╗
+    ██║     ██║██╔════╝ ██╔════╝ ██╔════╝ ██║  ██║╚══██╔══╝██╔════╝
+    ██║     ██║██║  ███╗██║  ███╗██║  ███╗███████║   ██║   ███████╗
+    ██║     ██║██║   ██║██║   ██║██║   ██║██╔══██║   ██║   ╚════██║
+    ███████╗██║╚██████╔╝╚██████╔╝╚██████╔╝██║  ██║   ██║   ███████║
+    ╚══════╝╚═╝ ╚═════╝  ╚═════╝  ╚═════╝ ╚═╝  ╚═╝   ╚═╝   ╚══════╝®
 
-   Christoph Kloss, christoph.kloss@cfdem.com
-   Copyright 2009-2012 JKU Linz
-   Copyright 2012-     DCS Computing GmbH, Linz
+    DEM simulation engine, released by
+    DCS Computing Gmbh, Linz, Austria
+    http://www.dcs-computing.com, office@dcs-computing.com
 
-   LIGGGHTS® and CFDEM® are registered trade marks of DCS Computing GmbH,
-   the producer of the LIGGGHTS® software and the CFDEM®coupling software
-   See http://www.cfdem.com/terms-trademark-policy for details.
+    LIGGGHTS® is part of CFDEM®project:
+    http://www.liggghts.com | http://www.cfdem.com
 
-   LIGGGHTS® is based on LAMMPS
-   LAMMPS - Large-scale Atomic/Molecular Massively Parallel Simulator
-   http://lammps.sandia.gov, Sandia National Laboratories
-   Steve Plimpton, sjplimp@sandia.gov
+    Core developer and main author:
+    Christoph Kloss, christoph.kloss@dcs-computing.com
 
-   This software is distributed under the GNU General Public License.
+    LIGGGHTS® is open-source, distributed under the terms of the GNU Public
+    License, version 2 or later. It is distributed in the hope that it will
+    be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
+    of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. You should have
+    received a copy of the GNU General Public License along with LIGGGHTS®.
+    If not, see http://www.gnu.org/licenses . See also top-level README
+    and LICENSE files.
 
-   See the README file in the top-level directory.
+    LIGGGHTS® and CFDEM® are registered trade marks of DCS Computing GmbH,
+    the producer of the LIGGGHTS® software and the CFDEM®coupling software
+    See http://www.cfdem.com/terms-trademark-policy for details.
+
+-------------------------------------------------------------------------
+    Contributing author and copyright for this file:
+
+    Andreas Aigner (JKU Linz)
+    Christoph Kloss (DCS Computing GmbH, Linz, JKU Linz)
+    Richard Berger (JKU Linz)
+
+    Copyright 2012-     DCS Computing GmbH, Linz
+    Copyright 2009-2012 JKU Linz
 ------------------------------------------------------------------------- */
 
-/* ----------------------------------------------------------------------
-   Contributing authors:
-   Christoph Kloss (JKU Linz, DCS Computing GmbH, Linz)
-   Andreas Aigner (JKU Linz)
-------------------------------------------------------------------------- */
 #ifdef ROLLING_MODEL
+
 ROLLING_MODEL(ROLLING_EPSD2,epsd2,3)
+
 #else
+
 #ifndef ROLLING_MODEL_EPSD2_H_
 #define ROLLING_MODEL_EPSD2_H_
+
 #include "contact_models.h"
 #include <algorithm>
 #include "math.h"
@@ -48,7 +65,7 @@ namespace ContactModels
   class RollingModel<ROLLING_EPSD2> : protected Pointers
   {
   public:
-    static const int MASK = CM_CONNECT_TO_PROPERTIES | CM_COLLISION | CM_NO_COLLISION;
+    static const int MASK = CM_CONNECT_TO_PROPERTIES | CM_SURFACES_INTERSECT | CM_SURFACES_CLOSE;
 
     RollingModel(class LAMMPS * lmp, IContactHistorySetup * hsetup) : Pointers(lmp), coeffRollFrict(NULL)
     {
@@ -69,36 +86,36 @@ namespace ContactModels
         error->cg(FLERR,"rolling model epsd2");
     }
 
-    void collision(CollisionData & cdata, ForceData & i_forces, ForceData & j_forces) 
+    void surfacesIntersect(SurfacesIntersectData & sidata, ForceData & i_forces, ForceData & j_forces) 
     {
       double r_torque[3];
       vectorZeroize3D(r_torque);
 
-      if(cdata.touch) *cdata.touch |= TOUCH_ROLLING_MODEL;
+      if(sidata.contact_flags) *sidata.contact_flags |= CONTACT_ROLLING_MODEL;
 
-      if(cdata.is_wall) {
-        const double wr1 = cdata.wr1;
-        const double wr2 = cdata.wr2;
-        const double wr3 = cdata.wr3;
-        const double radius = cdata.radi;
+      if(sidata.is_wall) {
+        const double wr1 = sidata.wr1;
+        const double wr2 = sidata.wr2;
+        const double wr3 = sidata.wr3;
+        const double radius = sidata.radi;
 
-        calcRollTorque(r_torque,cdata,radius,wr1,wr2,wr3);
+        calcRollTorque(r_torque,sidata,radius,wr1,wr2,wr3);
 
       } else {
         double wr_roll[3];
 
-        const int i = cdata.i;
-        const int j = cdata.j;
+        const int i = sidata.i;
+        const int j = sidata.j;
 
-        const double radi = cdata.radi;
-        const double radj = cdata.radj;
-        const double reff = cdata.is_wall ? radi : (radi*radj/(radi+radj));
+        const double radi = sidata.radi;
+        const double radj = sidata.radj;
+        const double reff = sidata.is_wall ? radi : (radi*radj/(radi+radj));
         const double * const * const omega = atom->omega;
 
         // relative rotational velocity
         vectorSubtract3D(omega[i],omega[j],wr_roll);
 
-        calcRollTorque(r_torque,cdata,reff,wr_roll[0],wr_roll[1],wr_roll[2]);
+        calcRollTorque(r_torque,sidata,reff,wr_roll[0],wr_roll[1],wr_roll[2]);
 
       }
 
@@ -110,33 +127,33 @@ namespace ContactModels
       j_forces.delta_torque[2] += r_torque[2];
     }
 
-    void noCollision(ContactData & cdata, ForceData&, ForceData&)
+    void surfacesClose(SurfacesCloseData & scdata, ForceData&, ForceData&)
     {
-      if(cdata.touch) *cdata.touch &= ~TOUCH_ROLLING_MODEL;
-      double * const c_history = &cdata.contact_history[history_offset];
+      if(scdata.contact_flags) *scdata.contact_flags &= ~CONTACT_ROLLING_MODEL;
+      double * const c_history = &scdata.contact_history[history_offset];
       c_history[0] = 0.0; // this is the r_torque_old
       c_history[1] = 0.0; // this is the r_torque_old
       c_history[2] = 0.0; // this is the r_torque_old
     }
 
-    void beginPass(CollisionData&, ForceData&, ForceData&){}
-    void endPass(CollisionData&, ForceData&, ForceData&){}
+    void beginPass(SurfacesIntersectData&, ForceData&, ForceData&){}
+    void endPass(SurfacesIntersectData&, ForceData&, ForceData&){}
 
   private:
     double ** coeffRollFrict;
     int history_offset;
 
-    inline void calcRollTorque(double (&r_torque)[3],const CollisionData & cdata,double reff,double wr1,double wr2,double wr3) {
+    inline void calcRollTorque(double (&r_torque)[3],const SurfacesIntersectData & sidata,double reff,double wr1,double wr2,double wr3) {
       double wr_n[3],wr_t[3];
 
-      const double enx = cdata.en[0];
-      const double eny = cdata.en[1];
-      const double enz = cdata.en[2];
+      const double enx = sidata.en[0];
+      const double eny = sidata.en[1];
+      const double enz = sidata.en[2];
 
       const double dt = update->dt; 
 
-      double * const c_history = &cdata.contact_history[history_offset]; // requires Style::TANGENTIAL == TANGENTIAL_HISTORY
-      const double rmu= coeffRollFrict[cdata.itype][cdata.jtype];
+      double * const c_history = &sidata.contact_history[history_offset]; // requires Style::TANGENTIAL == TANGENTIAL_HISTORY
+      const double rmu= coeffRollFrict[sidata.itype][sidata.jtype];
 
       // remove normal (torsion) part of relative rotation
       // use only tangential parts for rolling torque
@@ -149,7 +166,7 @@ namespace ContactModels
       wr_t[2] = wr3 - wr_n[2];
 
       // spring (reff depends on wall-particle or particle-particle contact)
-      const double kr = cdata.kt*reff*reff; 
+      const double kr = sidata.kt*reff*reff; 
 
       double dr_torque[3];
       vectorScalarMult3D(wr_t,dt*kr,dr_torque);
@@ -160,7 +177,7 @@ namespace ContactModels
 
       // limit max. torque
       const double r_torque_mag = vectorMag3D(r_torque);
-      const double r_torque_max = fabs(cdata.Fn)*reff*rmu;
+      const double r_torque_max = fabs(sidata.Fn)*reff*rmu;
       if(r_torque_mag > r_torque_max)
       {
         //printf("[%d] %e > %e\n", update->ntimestep, r_torque_mag, r_torque_max);
