@@ -1,32 +1,61 @@
 /* ----------------------------------------------------------------------
-   LIGGGHTS® - LAMMPS Improved for General Granular and Granular Heat
-   Transfer Simulations
+    This is the
 
-   LIGGGHTS® is part of CFDEM®project
-   www.liggghts.com | www.cfdem.com
+    ██╗     ██╗ ██████╗  ██████╗  ██████╗ ██╗  ██╗████████╗███████╗
+    ██║     ██║██╔════╝ ██╔════╝ ██╔════╝ ██║  ██║╚══██╔══╝██╔════╝
+    ██║     ██║██║  ███╗██║  ███╗██║  ███╗███████║   ██║   ███████╗
+    ██║     ██║██║   ██║██║   ██║██║   ██║██╔══██║   ██║   ╚════██║
+    ███████╗██║╚██████╔╝╚██████╔╝╚██████╔╝██║  ██║   ██║   ███████║
+    ╚══════╝╚═╝ ╚═════╝  ╚═════╝  ╚═════╝ ╚═╝  ╚═╝   ╚═╝   ╚══════╝®
 
-   This file was modified with respect to the release in LAMMPS
-   Modifications are Copyright 2009-2012 JKU Linz
-                     Copyright 2012-     DCS Computing GmbH, Linz
+    DEM simulation engine, released by
+    DCS Computing Gmbh, Linz, Austria
+    http://www.dcs-computing.com, office@dcs-computing.com
 
-   LIGGGHTS® and CFDEM® are registered trade marks of DCS Computing GmbH,
-   the producer of the LIGGGHTS® software and the CFDEM®coupling software
-   See http://www.cfdem.com/terms-trademark-policy for details.
+    LIGGGHTS® is part of CFDEM®project:
+    http://www.liggghts.com | http://www.cfdem.com
 
-   LAMMPS - Large-scale Atomic/Molecular Massively Parallel Simulator
-   http://lammps.sandia.gov, Sandia National Laboratories
-   Steve Plimpton, sjplimp@sandia.gov
+    Core developer and main author:
+    Christoph Kloss, christoph.kloss@dcs-computing.com
 
-   Copyright (2003) Sandia Corporation.  Under the terms of Contract
-   DE-AC04-94AL85000 with Sandia Corporation, the U.S. Government retains
-   certain rights in this software.  This software is distributed under
-   the GNU General Public License.
+    LIGGGHTS® is open-source, distributed under the terms of the GNU Public
+    License, version 2 or later. It is distributed in the hope that it will
+    be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
+    of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. You should have
+    received a copy of the GNU General Public License along with LIGGGHTS®.
+    If not, see http://www.gnu.org/licenses . See also top-level README
+    and LICENSE files.
 
-   See the README file in the top-level directory.
+    LIGGGHTS® and CFDEM® are registered trade marks of DCS Computing GmbH,
+    the producer of the LIGGGHTS® software and the CFDEM®coupling software
+    See http://www.cfdem.com/terms-trademark-policy for details.
+
+-------------------------------------------------------------------------
+    Contributing author and copyright for this file:
+    This file is from LAMMPS, but has been modified. Copyright for
+    modification:
+
+    Copyright 2012-     DCS Computing GmbH, Linz
+    Copyright 2009-2012 JKU Linz
+
+    Copyright of original file:
+    LAMMPS - Large-scale Atomic/Molecular Massively Parallel Simulator
+    http://lammps.sandia.gov, Sandia National Laboratories
+    Steve Plimpton, sjplimp@sandia.gov
+
+    Copyright (2003) Sandia Corporation.  Under the terms of Contract
+    DE-AC04-94AL85000 with Sandia Corporation, the U.S. Government retains
+    certain rights in this software.  This software is distributed under
+    the GNU General Public License.
 ------------------------------------------------------------------------- */
 
 #include "mpi.h"
 #include "math.h"
+#include "math_extra.h"
+#ifdef SUPERQUADRIC_ACTIVE_FLAG
+#include "math_extra_liggghts_superquadric.h"
+#include "atom_vec_superquadric.h"
+#endif
 #include "stdlib.h"
 #include "string.h"
 #include "set.h"
@@ -34,7 +63,6 @@
 #include "atom_vec.h"
 #include "atom_vec_ellipsoid.h"
 #include "atom_vec_line.h"
-#include "atom_vec_tri.h"
 #include "domain.h"
 #include "region.h"
 #include "group.h"
@@ -59,11 +87,11 @@ using namespace LAMMPS_NS;
 using namespace MathConst;
 
 enum{ATOM_SELECT,MOL_SELECT,TYPE_SELECT,GROUP_SELECT,REGION_SELECT};
-enum{TYPE,TYPE_FRACTION,MOLECULE,X,Y,Z,CHARGE,MASS,SHAPE,LENGTH,TRI,
-     DIPOLE,DIPOLE_RANDOM,QUAT,QUAT_RANDOM,THETA,ANGMOM,
+enum{TYPE,TYPE_FRACTION,MOLECULE,X,Y,Z,CHARGE,MASS,SHAPE,LENGTH,
+     DIPOLE,DIPOLE_RANDOM,QUAT,QUAT_RANDOM, QUAT_DIRECT, THETA,ANGMOM,
      DIAMETER,DENSITY,VOLUME,IMAGE,BOND,ANGLE,DIHEDRAL,IMPROPER,
      MESO_E,MESO_CV,MESO_RHO,INAME,DNAME,
-     VX,VY,VZ,OMEGAX,OMEGAY,OMEGAZ,PROPERTYPERATOM}; 
+     VX,VY,VZ,OMEGAX,OMEGAY,OMEGAZ,PROPERTYPERATOM,ROUNDNESS}; 
 
 #define BIG INT_MAX
 
@@ -171,9 +199,9 @@ void Set::command(int narg, char **arg)
       set(VY);
       iarg += 2;
     } else if (strcmp(arg[iarg],"vz") == 0) {
+      if (iarg+2 > narg) error->all(FLERR,"Illegal set command");
       if (strstr(arg[iarg+1],"v_") == arg[iarg+1]) varparse(arg[iarg+1],1);
-      else if (iarg+2 > narg) error->all(FLERR,"Illegal set command");
-      dvalue = force->numeric(FLERR,arg[iarg+1]);
+      else dvalue = force->numeric(FLERR,arg[iarg+1]);
       set(VZ);
       iarg += 2;
     } else if (strcmp(arg[iarg],"omegax") == 0) { 
@@ -221,11 +249,21 @@ void Set::command(int narg, char **arg)
       else yvalue = force->numeric(FLERR,arg[iarg+2]);
       if (strstr(arg[iarg+3],"v_") == arg[iarg+3]) varparse(arg[iarg+3],3);
       else zvalue = force->numeric(FLERR,arg[iarg+3]);
-      if (!atom->ellipsoid_flag)
+      if (!atom->ellipsoid_flag && !atom->superquadric_flag)
         error->all(FLERR,"Cannot set this attribute for this atom style");
       set(SHAPE);
       iarg += 4;
 
+    } else if (strcmp(arg[iarg],"roundness") == 0) {
+      if (iarg+3 > narg) error->all(FLERR,"Illegal set command");
+      if (strstr(arg[iarg+1],"v_") == arg[iarg+1]) varparse(arg[iarg+1],1);
+      else xvalue = force->numeric(FLERR,arg[iarg+1]);
+      if (strstr(arg[iarg+2],"v_") == arg[iarg+2]) varparse(arg[iarg+2],2);
+      else yvalue = force->numeric(FLERR,arg[iarg+2]);
+      if (!atom->superquadric_flag)
+        error->all(FLERR,"Cannot set this attribute for this atom style");
+      set(ROUNDNESS);
+      iarg += 3;
     } else if (strcmp(arg[iarg],"length") == 0) {
       if (iarg+2 > narg) error->all(FLERR,"Illegal set command");
       if (strstr(arg[iarg+1],"v_") == arg[iarg+1]) varparse(arg[iarg+1],1);
@@ -235,15 +273,6 @@ void Set::command(int narg, char **arg)
       set(LENGTH);
       iarg += 2;
 
-    } else if (strcmp(arg[iarg],"tri") == 0) {
-      if (iarg+2 > narg) error->all(FLERR,"Illegal set command");
-      if (strstr(arg[iarg+1],"v_") == arg[iarg+1]) varparse(arg[iarg+1],1);
-      else dvalue = force->numeric(FLERR,arg[iarg+1]);
-      if (!atom->tri_flag)
-        error->all(FLERR,"Cannot set this attribute for this atom style");
-      set(TRI);
-      iarg += 2;
-
     } else if (strcmp(arg[iarg],"dipole") == 0) {
       if (iarg+4 > narg) error->all(FLERR,"Illegal set command");
       if (strstr(arg[iarg+1],"v_") == arg[iarg+1]) varparse(arg[iarg+1],1);
@@ -270,7 +299,7 @@ void Set::command(int narg, char **arg)
       setrandom(DIPOLE_RANDOM);
       iarg += 3;
 
-    } else if (strcmp(arg[iarg],"quat") == 0) {
+    } else if (strcmp(arg[iarg],"quat") == 0 || strcmp(arg[iarg],"quat_direct") == 0) {
       if (iarg+5 > narg) error->all(FLERR,"Illegal set command");
       if (strstr(arg[iarg+1],"v_") == arg[iarg+1]) varparse(arg[iarg+1],1);
       else xvalue = force->numeric(FLERR,arg[iarg+1]);
@@ -280,15 +309,18 @@ void Set::command(int narg, char **arg)
       else zvalue = force->numeric(FLERR,arg[iarg+3]);
       if (strstr(arg[iarg+4],"v_") == arg[iarg+4]) varparse(arg[iarg+4],4);
       else wvalue = force->numeric(FLERR,arg[iarg+4]);
-      if (!atom->ellipsoid_flag && !atom->tri_flag)
+      if (!atom->ellipsoid_flag && !atom->tri_flag && !atom->superquadric_flag)
         error->all(FLERR,"Cannot set this attribute for this atom style");
+      if(strcmp(arg[iarg],"quat") == 0)
       set(QUAT);
+      else
+        set(QUAT_DIRECT);
       iarg += 5;
 
     } else if (strcmp(arg[iarg],"quat/random") == 0) {
       if (iarg+2 > narg) error->all(FLERR,"Illegal set command");
       ivalue = force->inumeric(FLERR,arg[iarg+1]);
-      if (!atom->ellipsoid_flag && !atom->tri_flag)
+      if (!atom->ellipsoid_flag && !atom->tri_flag && !atom->superquadric_flag)
         error->all(FLERR,"Cannot set this attribute for this atom style");
       if (ivalue <= 0)
         error->all(FLERR,"Invalid random number seed in set command");
@@ -672,7 +704,9 @@ void Set::set(int keyword)
   AtomVecEllipsoid *avec_ellipsoid =
     (AtomVecEllipsoid *) atom->style_match("ellipsoid");
   AtomVecLine *avec_line = (AtomVecLine *) atom->style_match("line");
-  AtomVecTri *avec_tri = (AtomVecTri *) atom->style_match("tri");
+  #ifdef SUPERQUADRIC_ACTIVE_FLAG
+  AtomVecSuperquadric *avec_superquadric = (AtomVecSuperquadric *) atom->style_match("superquadric");
+  #endif
 
   int nlocal = atom->nlocal;
   for (int i = 0; i < nlocal; i++) {
@@ -718,10 +752,14 @@ void Set::set(int keyword)
         
         if(atom->rmass_flag && atom->density_flag && atom->density[i] > 0.)
         {
+          if(atom->superquadric_flag)
+            error->one(FLERR,"Diameter command is incompatible with superquadric atom style!");
+          else {
           if (domain->dimension == 2)
             atom->rmass[i] = MY_PI * atom->radius[i]*atom->radius[i] * atom->density[i];
           else
             atom->rmass[i] = 4.0*MY_PI/3.0 * atom->radius[i]*atom->radius[i]*atom->radius[i] * atom->density[i];
+          }
         }
     }
     else if (keyword == VOLUME) {
@@ -741,7 +779,44 @@ void Set::set(int keyword)
         if (xvalue == 0.0 || yvalue == 0.0 || zvalue == 0.0)
           error->one(FLERR,"Invalid shape in set command");
       }
-      avec_ellipsoid->set_shape(i,0.5*xvalue,0.5*yvalue,0.5*zvalue);
+      if(avec_ellipsoid)
+        avec_ellipsoid->set_shape(i,0.5*xvalue,0.5*yvalue,0.5*zvalue);
+      #ifdef SUPERQUADRIC_ACTIVE_FLAG
+      else if(avec_superquadric) {
+        atom->shape[i][0] = xvalue;
+        atom->shape[i][1] = yvalue;
+        atom->shape[i][2] = zvalue;
+        MathExtraLiggghtsSuperquadric::bounding_sphere_radius_superquadric(atom->shape[i], atom->roundness[i], atom->radius+i); //re-calculate bounding sphere radius
+        MathExtraLiggghtsSuperquadric::volume_superquadric(atom->shape[i], atom->roundness[i], atom->volume+i); //re-calculate volume
+        atom->rmass[i] = atom->volume[i] * atom->density[i]; //re-calculate mass
+        MathExtraLiggghtsSuperquadric::inertia_superquadric(atom->shape[i], atom->roundness[i], atom->density[i], atom->inertia[i]); //re-calculate inertia tensor
+
+      }
+      #endif // SUPERQUADRIC_ACTIVE_FLAG
+      else
+        error->one(FLERR,"Cannot set shape for this type of atom");
+    }
+   //set roundness parameters for superquadric *
+    else if (keyword == ROUNDNESS) {
+      if (xvalue <= 0.0 || yvalue <= 0.0)
+        error->one(FLERR,"Invalid roundness (<=0) in set command");
+      if (xvalue > 1.0 || yvalue > 1.0) {
+        error->one(FLERR,"Invalid shape in set command (>1)");
+      }
+      if(0) {}
+      #ifdef SUPERQUADRIC_ACTIVE_FLAG
+      else if(avec_superquadric) {
+        atom->roundness[i][0] = xvalue;
+        atom->roundness[i][1] = yvalue;
+        MathExtraLiggghtsSuperquadric::bounding_sphere_radius_superquadric(atom->shape[i], atom->roundness[i], atom->radius+i); //re-calculate bounding sphere radius
+        MathExtraLiggghtsSuperquadric::volume_superquadric(atom->shape[i], atom->roundness[i], atom->volume+i); //re-calculate volume
+        atom->rmass[i] = atom->density[i] * atom->volume[i]; //re-calculate mass
+        MathExtraLiggghtsSuperquadric::inertia_superquadric(atom->shape[i], atom->roundness[i], atom->density[i], atom->inertia[i]); //re-calculate inertia tensor
+
+      }
+      #endif // SUPERQUADRIC_ACTIVE_FLAG
+      else
+        error->one(FLERR,"Cannot set shape for this type of atom");
     }
     // set desired per-atom property
     else if (keyword == PROPERTYPERATOM) { 
@@ -786,13 +861,6 @@ void Set::set(int keyword)
       avec_line->set_length(i,dvalue);
     }
 
-    // set corners of tri particle
-
-    else if (keyword == TRI) {
-      if (dvalue < 0.0) error->one(FLERR,"Invalid length in set command");
-      avec_tri->set_equilateral(i,dvalue);
-    }
-
     // set rmass via density
     // if radius > 0.0, treat as sphere
     // if shape > 0.0, treat as ellipsoid
@@ -805,10 +873,22 @@ void Set::set(int keyword)
       if (atom->radius_flag && atom->radius[i] > 0.0)
       {
           atom->density[i] = dvalue;
-          if (domain->dimension == 2)
-            atom->rmass[i] = MY_PI * atom->radius[i]*atom->radius[i] * atom->density[i]; 
-          else
-            atom->rmass[i] = 4.0*MY_PI/3.0 * atom->radius[i]*atom->radius[i]*atom->radius[i] * atom->density[i]; 
+          if(!atom->superquadric_flag) {
+              if (domain->dimension == 2)
+                atom->rmass[i] = MY_PI * atom->radius[i]*atom->radius[i] * atom->density[i]; 
+              else
+                atom->rmass[i] = 4.0*MY_PI/3.0 * atom->radius[i]*atom->radius[i]*atom->radius[i] * atom->density[i]; 
+          }
+          else {
+            #ifdef SUPERQUADRIC_ACTIVE_FLAG
+            if (domain->dimension == 3) {
+              atom->rmass[i] = atom->density[i] * atom->volume[i];
+              MathExtraLiggghtsSuperquadric::inertia_superquadric(atom->shape[i], atom->roundness[i], atom->density[i], atom->inertia[i]);
+            }
+            else
+              error->one(FLERR,"Superquadrics are implemented only in 3D");
+            #endif // SUPERQUADRIC_ACTIVE_FLAG
+          }
       }
       else if (atom->density_flag)
         atom->density[i] = dvalue;
@@ -818,18 +898,8 @@ void Set::set(int keyword)
       } else if (atom->line_flag && atom->line[i] >= 0) {
         double length = avec_line->bonus[atom->line[i]].length;
         atom->rmass[i] = length * dvalue;
-      } else if (atom->tri_flag && atom->tri[i] >= 0) {
-        double *c1 = avec_tri->bonus[atom->tri[i]].c1;
-        double *c2 = avec_tri->bonus[atom->tri[i]].c2;
-        double *c3 = avec_tri->bonus[atom->tri[i]].c3;
-        double c2mc1[2],c3mc1[3];
-        MathExtra::sub3(c2,c1,c2mc1);
-        MathExtra::sub3(c3,c1,c3mc1);
-        double norm[3];
-        MathExtra::cross3(c2mc1,c3mc1,norm);
-        double area = 0.5 * MathExtra::len3(norm);
-        atom->rmass[i] = area * dvalue;
-      } else atom->rmass[i] = dvalue;
+      }
+       else atom->rmass[i] = dvalue;
     }
 
     // set dipole moment
@@ -845,21 +915,31 @@ void Set::set(int keyword)
 
     // set quaternion orientation of ellipsoid or tri particle
 
-    else if (keyword == QUAT) {
+    else if (keyword == QUAT || keyword == QUAT_DIRECT ) {
       double *quat = NULL;
       if (avec_ellipsoid && atom->ellipsoid[i] >= 0)
         quat = avec_ellipsoid->bonus[atom->ellipsoid[i]].quat;
-      else if (avec_tri && atom->tri[i] >= 0)
-        quat = avec_tri->bonus[atom->tri[i]].quat;
+      #ifdef SUPERQUADRIC_ACTIVE_FLAG
+      else if (avec_superquadric)
+        quat = avec_superquadric->return_quat_ptr(i);
+      #endif
       else
         error->one(FLERR,"Cannot set quaternion for atom that has none");
 
+      if(keyword == QUAT) {
       double theta2 = MY_PI2 * wvalue/180.0;
       double sintheta2 = sin(theta2);
       quat[0] = cos(theta2);
       quat[1] = xvalue * sintheta2;
       quat[2] = yvalue * sintheta2;
       quat[3] = zvalue * sintheta2;
+      } else {
+        //direct quaternion components setup
+        quat[0] = xvalue;
+        quat[1] = yvalue;
+        quat[2] = zvalue;
+        quat[3] = wvalue;
+      }
       MathExtra::qnormalize(quat);
     }
 
@@ -927,7 +1007,9 @@ void Set::setrandom(int keyword)
   AtomVecEllipsoid *avec_ellipsoid =
     (AtomVecEllipsoid *) atom->style_match("ellipsoid");
   atom->style_match("line"); // DEAD CODE?
-  AtomVecTri *avec_tri = (AtomVecTri *) atom->style_match("tri");
+  #ifdef SUPERQUADRIC_ACTIVE_FLAG
+  AtomVecSuperquadric *avec_superquadric = (AtomVecSuperquadric *) atom->style_match("superquadric");
+  #endif
 
   RanPark *random = new RanPark(lmp,1);
   double **x = atom->x;
@@ -1000,8 +1082,10 @@ void Set::setrandom(int keyword)
         if (select[i]) {
           if (avec_ellipsoid && atom->ellipsoid[i] >= 0)
             quat = avec_ellipsoid->bonus[atom->ellipsoid[i]].quat;
-          else if (avec_tri && atom->tri[i] >= 0)
-            quat = avec_tri->bonus[atom->tri[i]].quat;
+          #ifdef SUPERQUADRIC_ACTIVE_FLAG
+          else if (avec_superquadric)
+            quat = avec_superquadric->return_quat_ptr(i);
+          #endif
           else
             error->one(FLERR,"Cannot set quaternion for atom that has none");
 
